rregex 1.10.12 → 1.10.13
This diff represents the content of publicly available package versions that have been released to one of the supported registries. The information contained in this diff is provided for informational purposes only and reflects changes between package versions as they appear in their respective public registries.
- package/README.md +11 -11
- package/lib/cf.d.ts +654 -657
- package/lib/cf.mjs +1 -1
- package/lib/commonjs.cjs +792 -945
- package/lib/commonjs.d.cts +1257 -0
- package/lib/esm.d.ts +621 -628
- package/lib/esm.mjs +793 -945
- package/lib/rregex.wasm +0 -0
- package/lib/rregex.wasm.d.ts +34 -30
- package/lib/standalone.d.ts +652 -655
- package/lib/standalone.js +1011 -1148
- package/lib/types.d.ts +654 -657
- package/lib/web.d.ts +654 -657
- package/lib/web.js +820 -957
- package/package.json +37 -4
- package/lib/commonjs.d.ts +0 -1264
package/README.md
CHANGED
|
@@ -66,28 +66,28 @@ In general terms `rregex` is at least 1 order of magnitud slower than the native
|
|
|
66
66
|
|
|
67
67
|
| benchmark | time (avg) | iter/s |
|
|
68
68
|
| --------- | -------------: | ------: |
|
|
69
|
-
| RegExp |
|
|
70
|
-
| RRegex |
|
|
69
|
+
| RegExp | 254.8 µs/iter | 3,925.0 |
|
|
70
|
+
| RRegex | 1.7 ms/iter | 589.9 |
|
|
71
71
|
|
|
72
|
-
> summary: `RegExp` is
|
|
72
|
+
> summary: `RegExp` is 6.65x faster than `RRegex`
|
|
73
73
|
|
|
74
74
|
### IP
|
|
75
75
|
|
|
76
|
-
| benchmark | time (avg) |
|
|
77
|
-
| --------- | ------------: |
|
|
78
|
-
| RegExp |
|
|
79
|
-
| RRegex |
|
|
76
|
+
| benchmark | time (avg) | iter/s |
|
|
77
|
+
| --------- | ------------: | --------: |
|
|
78
|
+
| RegExp | 39.1 µs/iter | 25,600.0 |
|
|
79
|
+
| RRegex | 1.4 ms/iter | 698.1 |
|
|
80
80
|
|
|
81
|
-
> summary: `RegExp` is
|
|
81
|
+
> summary: `RegExp` is 36.67x faster than `RRegex`
|
|
82
82
|
|
|
83
83
|
### URI
|
|
84
84
|
|
|
85
85
|
| benchmark | time (avg) | iter/s |
|
|
86
86
|
| --------- | -------------: | ----------: |
|
|
87
|
-
| RegExp |
|
|
88
|
-
| RRegex |
|
|
87
|
+
| RegExp | 422.7 ns/iter | 2,366,000.0 |
|
|
88
|
+
| RRegex | 1.5 ms/iter | 652.6 |
|
|
89
89
|
|
|
90
|
-
> summary: `RegExp` is
|
|
90
|
+
> summary: `RegExp` is 3625x faster than `RRegex`
|
|
91
91
|
|
|
92
92
|
| benckmarks | benckmarks |
|
|
93
93
|
| ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
|